pub fn render(output: SumOfProducts, input: &[Vec<f64>]) -> StringExpand description
Formats the computation as aligned formulas with a sum line.
pub fn render(output: SumOfProducts, input: &[Vec<f64>]) -> StringFormats the computation as aligned formulas with a sum line.